@@ -1,15 +1,15 @@
 package Sah::Schema::dirname::unix;
 
 # AUTHOR
-our $DATE = '2019-11-28'; # DATE
+our $DATE = '2019-11-29'; # DATE
 our $DIST = 'Sah-Schemas-Path'; # DIST
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 our $schema = ["str" => {
     summary => 'Filesystem directory name on a Unix system',
     match => '\A(?:/|/?(?:[^/\0]{1,255})(?:/[^/\0]{1,255})?)\z',
     'x.perl.coerce_rules' => [
-        'From_str::StripSlashes',
+        'From_str::strip_slashes',
     ],
 }, {}];
 
@@ -28,7 +28,7 @@ Sah::Schema::dirname::unix - Filesystem directory name on a Unix system
 
 =head1 VERSION
 
-This document describes version 0.009 of Sah::Schema::dirname::unix (from Perl distribution Sah-Schemas-Path), released on 2019-11-28.
+This document describes version 0.010 of Sah::Schema::dirname::unix (from Perl distribution Sah-Schemas-Path), released on 2019-11-29.
 
 =head1 HOMEPAGE
 
